---
hide:
  - navigation
  - toc
---

!!! new "This sandbox is powered by [Pyodide](https://github.com/pyodide/pyodide). Preview, convert, interpolate, and explore!"

```color
import coloraide
coloraide.__version__
Color('red')
```

--8<--
playground.txt

refs.txt
--8<--
